@@ -66,7 +66,7 @@ static void _xfdashboard_window_tracker_backend_gdk_on_stage_state_changed(WnckW
 																			WnckWindowState inNewValue,
 																			gpointer inUserData)
 {
-	XfdashboardWindowTrackerWindowX11			*stageWindow;
+	G_GNUC_UNUSED XfdashboardWindowTrackerWindowX11			*stageWindow;
 
 	g_return_if_fail(WNCK_IS_WINDOW(inWindow));
 	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW_X11(inUserData));
@@ -419,7 +419,7 @@ static XfdashboardWindowTrackerWindow* _xfdashboard_window_tracker_backend_gdk_w
 static ClutterStage* _xfdashboard_window_tracker_backend_gdk_window_tracker_backend_get_stage_from_window(XfdashboardWindowTrackerBackend *inBackend,
 																											XfdashboardWindowTrackerWindow *inStageWindow)
 {
-	XfdashboardWindowTrackerBackendGDK			*self;
+	G_GNUC_UNUSED XfdashboardWindowTrackerBackendGDK			*self;
 	XfdashboardWindowTrackerWindowX11			*stageWindow;
 	WnckWindow									*stageWnckWindow;
 	Window										stageXWindow;
