@@ -79,6 +79,8 @@ struct _XfdashboardSettingsPrivate
 	gchar											**bindingFiles;
 	gchar											**themeSearchPaths;
 	gchar											**pluginSearchPaths;
+	gchar											*configPath;
+	gchar											*dataPath;
 
 	/* Instance related */
 	GList											*plugins;
@@ -123,6 +125,8 @@ enum
 	PROP_BINDING_FILES,
 	PROP_THEME_SEARCH_PATHS,
 	PROP_PLUGIN_SEARCH_PATHS,
+	PROP_CONFIG_PATH,
+	PROP_DATA_PATH,
 
 	PROP_LAST
 };
@@ -226,6 +230,176 @@ static void _xfdashboard_settings_on_plugin_settings_changed(XfdashboardSettings
 	}
 }
 
+/* Set the list of file locations where to load and merge key and mouse bindings
+ * from. The binding files are loaded in given order and the binding from the
+ * latter binding files will override the existing binding of the former ones.
+ * The list of file locations must be a %NULL-terminated list of strings where
+ * each string contains the absolute file path to a binding file. Non-existing
+ * files will be silently skipped and ignored. Set to NULL if not interested in
+ * any binding.
+ */
+static void _xfdashboard_settings_set_binding_files(XfdashboardSettings *self, const gchar **inFileLocations)
+{
+	XfdashboardSettingsPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
+	g_return_if_fail(inFileLocations==NULL || *inFileLocations);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(!xfdashboard_strv_equal((const gchar**)priv->bindingFiles, inFileLocations))
+	{
+		/* Set value */
+		if(priv->bindingFiles)
+		{
+			g_strfreev(priv->bindingFiles);
+			priv->bindingFiles=NULL;
+		}
+
+		if(inFileLocations)
+		{
+			priv->bindingFiles=g_strdupv((gchar**)inFileLocations);
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_BINDING_FILES]);
+	}
+}
+
+/* Set the list of paths where to lookup themes at settings. The themes are
+ * searched in the %NULL-terminated list of paths in given order and the first
+ * path containing the theme will be used. Even if it is possible to set it to
+ * NULL, it is not adviced as no theme can be loaded in this case.
+ */
+static void _xfdashboard_settings_set_theme_search_paths(XfdashboardSettings *self, const gchar **inSearchPaths)
+{
+	XfdashboardSettingsPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
+	g_return_if_fail(inSearchPaths==NULL || *inSearchPaths);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(!xfdashboard_strv_equal((const gchar**)priv->themeSearchPaths, inSearchPaths))
+	{
+		/* Set value */
+		if(priv->themeSearchPaths)
+		{
+			g_strfreev(priv->themeSearchPaths);
+			priv->themeSearchPaths=NULL;
+		}
+
+		if(inSearchPaths)
+		{
+			priv->themeSearchPaths=g_strdupv((gchar**)inSearchPaths);
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_THEME_SEARCH_PATHS]);
+	}
+}
+
+/* Set the list of paths where to lookup plugins at settings. The plugins are
+ * searched in the %NULL-terminated list of paths in given order and the first
+ * path containing the plugin will be used. Even if it is possible to set it to
+ * NULL, it is not adviced as no plugin can be loaded in this case.
+ */
+static void _xfdashboard_settings_set_plugin_search_paths(XfdashboardSettings *self, const gchar **inSearchPaths)
+{
+	XfdashboardSettingsPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
+	g_return_if_fail(inSearchPaths==NULL || *inSearchPaths);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(!xfdashboard_strv_equal((const gchar**)priv->pluginSearchPaths, inSearchPaths))
+	{
+		/* Set value */
+		if(priv->pluginSearchPaths)
+		{
+			g_strfreev(priv->pluginSearchPaths);
+			priv->pluginSearchPaths=NULL;
+		}
+
+		if(inSearchPaths)
+		{
+			priv->pluginSearchPaths=g_strdupv((gchar**)inSearchPaths);
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_PLUGIN_SEARCH_PATHS]);
+	}
+}
+
+/* Set the base path of configuration files for application or NULL to disable
+ * application specific configuration files.
+ */
+static void _xfdashboard_settings_set_config_path(XfdashboardSettings *self, const gchar *inPath)
+{
+	XfdashboardSettingsPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
+	g_return_if_fail(!inPath || *inPath);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(g_strcmp0(priv->configPath, inPath)!=0)
+	{
+		/* Set value */
+		if(priv->configPath)
+		{
+			g_free(priv->configPath);
+			priv->configPath=NULL;
+		}
+
+		if(inPath)
+		{
+			priv->configPath=g_strdup(inPath);
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_CONFIG_PATH]);
+	}
+}
+
+/* Set the base path of data files for application or NULL to disable application
+ * specific data files.
+ */
+static void _xfdashboard_settings_set_data_path(XfdashboardSettings *self, const gchar *inPath)
+{
+	XfdashboardSettingsPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
+	g_return_if_fail(!inPath || *inPath);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(g_strcmp0(priv->dataPath, inPath)!=0)
+	{
+		/* Set value */
+		if(priv->dataPath)
+		{
+			g_free(priv->dataPath);
+			priv->dataPath=NULL;
+		}
+
+		if(inPath)
+		{
+			priv->dataPath=g_strdup(inPath);
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_CONFIG_PATH]);
+	}
+}
+
+
 /* IMPLEMENTATION: GObject */
 
 /* Default nofity signal handler */
@@ -378,15 +552,23 @@ static void _xfdashboard_settings_set_property(GObject *inObject,
 
 		/* Static runtime settings */
 		case PROP_BINDING_FILES:
-			xfdashboard_settings_set_binding_files(self, (const gchar**)g_value_get_boxed(inValue));
+			_xfdashboard_settings_set_binding_files(self, (const gchar**)g_value_get_boxed(inValue));
 			break;
 
 		case PROP_THEME_SEARCH_PATHS:
-			xfdashboard_settings_set_theme_search_paths(self, (const gchar**)g_value_get_boxed(inValue));
+			_xfdashboard_settings_set_theme_search_paths(self, (const gchar**)g_value_get_boxed(inValue));
 			break;
 
 		case PROP_PLUGIN_SEARCH_PATHS:
-			xfdashboard_settings_set_plugin_search_paths(self, (const gchar**)g_value_get_boxed(inValue));
+			_xfdashboard_settings_set_plugin_search_paths(self, (const gchar**)g_value_get_boxed(inValue));
+			break;
+
+		case PROP_CONFIG_PATH:
+			_xfdashboard_settings_set_config_path(self, g_value_get_string(inValue));
+			break;
+
+		case PROP_DATA_PATH:
+			_xfdashboard_settings_set_data_path(self, g_value_get_string(inValue));
 			break;
 
 		/* Unknown settings ;) */
@@ -487,6 +669,14 @@ static void _xfdashboard_settings_get_property(GObject *inObject,
 			g_value_set_boxed(outValue, self->priv->pluginSearchPaths);
 			break;
 
+		case PROP_CONFIG_PATH:
+			g_value_set_string(outValue, self->priv->configPath);
+			break;
+
+		case PROP_DATA_PATH:
+			g_value_set_string(outValue, self->priv->dataPath);
+			break;
+
 		/* Unknown settings ;) */
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(inObject, inPropID, inSpec);
@@ -741,6 +931,7 @@ static void xfdashboard_settings_class_init(XfdashboardSettingsClass *klass)
 	 * A %NULL-terminated list of strings where each one contains the file location of a binding
 	 * file. The binding files are loaded in the given order and merged wherby the latter bindings
 	 * override the former ones. If a file in this list does not exist, it will be skipped silently.
+	 * Set to %NULL or leave the default value untouched if not interested in any binding.
 	 */
 	XfdashboardSettingsProperties[PROP_BINDING_FILES]=
 		g_param_spec_boxed("binding-files",
@@ -754,7 +945,9 @@ static void xfdashboard_settings_class_init(XfdashboardSettingsClass *klass)
 	 *
 	 * A %NULL-terminated list of strings where each one contains the path the lookup a requested
 	 * theme at. The theme is looked up in the order given at this search path list and the first
-	 * path containing it will be used.
+	 * path containing it will be used. Even if it is possible to set it to %NULL or to keep the
+	 * default empty value, it is not adviced not to set this property as no theme can be loaded
+	 * in this case.
 	 */
 	XfdashboardSettingsProperties[PROP_THEME_SEARCH_PATHS]=
 		g_param_spec_boxed("theme-search-paths",
@@ -768,7 +961,9 @@ static void xfdashboard_settings_class_init(XfdashboardSettingsClass *klass)
 	 *
 	 * A %NULL-terminated list of strings where each one contains the path the lookup a requested
 	 * plug-in at. The plug-in is looked up in the order given at this search path list and the first
-	 * path containing it will be used.
+	 * path containing it will be used. Even if it is possible to set it to %NULL or to keep the
+	 * default empty value, it is not adviced not to set this property as as no plugin can be loaded
+	 * in this case.
 	 */
 	XfdashboardSettingsProperties[PROP_PLUGIN_SEARCH_PATHS]=
 		g_param_spec_boxed("plugin-search-paths",
@@ -777,6 +972,31 @@ static void xfdashboard_settings_class_init(XfdashboardSettingsClass *klass)
 								G_TYPE_STRV,
 								G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
+	/**
+	 * XfdashboardSettings:config-path:
+	 *
+	 * The base path of configuration files of application or NULL to disable application specific
+	 * configuration files.
+	 */
+	XfdashboardSettingsProperties[PROP_CONFIG_PATH]=
+		g_param_spec_string("config-path",
+								"Configuration path",
+								"Base path to configuration files of application",
+								NULL,
+								G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
+	/**
+	 * XfdashboardSettings:data-path:
+	 *
+	 * The base path of data files of application or NULL to disable application specific data files.
+	 */
+	XfdashboardSettingsProperties[PROP_DATA_PATH]=
+		g_param_spec_string("data-path",
+								"Data path",
+								"Base path to data files of application",
+								NULL,
+								G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardSettingsProperties);
 
 	/* Define signals */
@@ -797,7 +1017,7 @@ static void xfdashboard_settings_class_init(XfdashboardSettingsClass *klass)
 						G_STRUCT_OFFSET(XfdashboardSettingsClass, changed),
 						NULL,
 						NULL,
-						_xfdashboard_marshal_VOID__STRING_OBJECT,
+						_xfdashboard_marshal_VOID__STRING_PARAM,
 						G_TYPE_NONE,
 						2,
 						G_TYPE_STRING,
@@ -829,6 +1049,8 @@ static void xfdashboard_settings_init(XfdashboardSettings *self)
 	priv->bindingFiles=NULL;
 	priv->themeSearchPaths=NULL;
 	priv->pluginSearchPaths=NULL;
+	priv->configPath=NULL;
+	priv->dataPath=NULL;
 
 	/* Set default applications search provider settings */
 	priv->applicationsSearchProviderSortMode=DEFAULT_APPLICATIONS_SEARCH_PROVIDER_SORT_MODE;
@@ -962,7 +1184,7 @@ void xfdashboard_settings_remove_plugin(XfdashboardSettings *self, XfdashboardPl
 			g_strcmp0(xfdashboard_plugin_get_id(entry->plugin), xfdashboard_plugin_get_id(inPlugin))==0)
 		{
 			/* Remove entry from list */
-			priv->plugins=g_list_remove(priv->plugins, currentIter);
+			priv->plugins=g_list_remove_link(priv->plugins, currentIter);
 
 			/* Call virtual funtion for plugin removed */
 			if(klass->plugin_removed)
@@ -1808,48 +2030,6 @@ const gchar** xfdashboard_settings_get_binding_files(XfdashboardSettings *self)
 	return((const gchar**)self->priv->bindingFiles);
 }
 
-/**
- * xfdashboard_settings_set_binding_files:
- * @self: A #XfdashboardSettings
- * @inFileLocations: The list of file locations for binding files
- *
- * Sets the list of file locations where to load and merge key and mouse bindings
- * from. The binding files are loaded in given order and the binding from the
- * latter binding files will override the existing binding of the former ones.
- * The list of file locations at @inFileLocations must be a %NULL-terminated
- * list of strings where each string contains the absolute file path to a binding
- * file. Non-existing files will be silently skipped and ignored. Set to %NULL
- * if not interested in any binding.
- */
-void xfdashboard_settings_set_binding_files(XfdashboardSettings *self, const gchar **inFileLocations)
-{
-	XfdashboardSettingsPrivate		*priv;
-
-	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
-	g_return_if_fail(inFileLocations==NULL || *inFileLocations);
-
-	priv=self->priv;
-
-	/* Set value if changed */
-	if(!xfdashboard_strv_equal((const gchar**)priv->bindingFiles, inFileLocations))
-	{
-		/* Set value */
-		if(priv->bindingFiles)
-		{
-			g_strfreev(priv->bindingFiles);
-			priv->bindingFiles=NULL;
-		}
-
-		if(inFileLocations)
-		{
-			priv->bindingFiles=g_strdupv((gchar**)inFileLocations);
-		}
-
-		/* Notify about property change */
-		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_BINDING_FILES]);
-	}
-}
-
 /**
  * xfdashboard_settings_get_theme_search_paths:
  * @self: A #XfdashboardSettings
@@ -1867,46 +2047,6 @@ const gchar** xfdashboard_settings_get_theme_search_paths(XfdashboardSettings *s
 	return((const gchar**)self->priv->themeSearchPaths);
 }
 
-/**
- * xfdashboard_settings_set_theme_search_paths:
- * @self: A #XfdashboardSettings
- * @inSearchPaths: The list of paths to lookup themes at
- *
- * Sets the list of paths where to lookup themes at in settings at @self.
- * The themes are search in the %NULL-terminated list of paths at @inSearchPaths
- * in given order and the first paths containing the theme will be used.
- * Even if it is possible to set it to %NULL, it is not adviced as no theme
- * can be loaded in this case.
- */
-void xfdashboard_settings_set_theme_search_paths(XfdashboardSettings *self, const gchar **inSearchPaths)
-{
-	XfdashboardSettingsPrivate		*priv;
-
-	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
-	g_return_if_fail(inSearchPaths==NULL || *inSearchPaths);
-
-	priv=self->priv;
-
-	/* Set value if changed */
-	if(!xfdashboard_strv_equal((const gchar**)priv->themeSearchPaths, inSearchPaths))
-	{
-		/* Set value */
-		if(priv->themeSearchPaths)
-		{
-			g_strfreev(priv->themeSearchPaths);
-			priv->themeSearchPaths=NULL;
-		}
-
-		if(inSearchPaths)
-		{
-			priv->themeSearchPaths=g_strdupv((gchar**)inSearchPaths);
-		}
-
-		/* Notify about property change */
-		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_THEME_SEARCH_PATHS]);
-	}
-}
-
 /**
  * xfdashboard_settings_get_plugin_search_paths:
  * @self: A #XfdashboardSettings
@@ -1925,41 +2065,41 @@ const gchar** xfdashboard_settings_get_plugin_search_paths(XfdashboardSettings *
 }
 
 /**
- * xfdashboard_settings_set_plugin_search_paths:
+ * xfdashboard_settings_get_config_path:
  * @self: A #XfdashboardSettings
- * @inSearchPaths: The list of paths to lookup plugins at
  *
- * Sets the list of paths where to lookup plugins at in settings at @self.
- * The plugins are search in the %NULL-terminated list of paths at @inSearchPaths
- * in given order and the first path containing the plugin will be used.
- * Even if it is possible to set it to %NULL, it is not adviced as no plugin
- * can be loaded in this case.
+ * Retrieves the base path of configuration files of application in settings
+ * at @self.
+ *
+ * NOTE: To retrieve the base path of configuration files for a specific plugin,
+ * use xfdashboard_plugin_get_config_path() instead.
+ *
+ * Return value: The base path of configuration files or %NULL if support for
+ *   configuration files is disabled.
  */
-void xfdashboard_settings_set_plugin_search_paths(XfdashboardSettings *self, const gchar **inSearchPaths)
+const gchar* xfdashboard_settings_get_config_path(XfdashboardSettings *self)
 {
-	XfdashboardSettingsPrivate		*priv;
+	g_return_val_if_fail(XFDASHBOARD_IS_SETTINGS(self), NULL);
 
-	g_return_if_fail(XFDASHBOARD_IS_SETTINGS(self));
-	g_return_if_fail(inSearchPaths==NULL || *inSearchPaths);
+	return(self->priv->configPath);
+}
 
-	priv=self->priv;
+/**
+ * xfdashboard_settings_get_data_path:
+ * @self: A #XfdashboardSettings
+ *
+ * Retrieves the base path of data files of application in settings
+ * at @self.
+ *
+ * NOTE: To retrieve the base path of data files for a specific plugin, use
+ * xfdashboard_plugin_get_data_path() instead.
+ *
+ * Return value: The base path of data files or %NULL if support for
+ *   data files is disabled.
+ */
+const gchar* xfdashboard_settings_get_data_path(XfdashboardSettings *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_SETTINGS(self), NULL);
 
-	/* Set value if changed */
-	if(!xfdashboard_strv_equal((const gchar**)priv->pluginSearchPaths, inSearchPaths))
-	{
-		/* Set value */
-		if(priv->pluginSearchPaths)
-		{
-			g_strfreev(priv->pluginSearchPaths);
-			priv->pluginSearchPaths=NULL;
-		}
-
-		if(inSearchPaths)
-		{
-			priv->pluginSearchPaths=g_strdupv((gchar**)inSearchPaths);
-		}
-
-		/* Notify about property change */
-		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardSettingsProperties[PROP_PLUGIN_SEARCH_PATHS]);
-	}
+	return(self->priv->dataPath);
 }
